package com.muyu.pay.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.pay.domain.req.OrderCustomerAddReq;
import com.muyu.pay.domain.req.OrderCustomerUpdateReq;
import lombok.*;
import lombok.experimental.SuperBuilder;

import java.util.function.Supplier;

/**
 * @Classname OrderPayCustomer
 * @Description TODO
 * @Date 2024/8/8 下午4:05
 * @Created by 杨旭飞
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName(value = "order_pay_customer", autoResultMap = true)
public class OrderPayCustomer extends BaseEntity {

    /**
     * 主键
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 服务/客户名称
     */
    private String appName;

    /**
     * 服务/客户编码
     */
    private String appCode;

    /**
     * 服务/客户描述
     */
    private String appDesc;

    /**
     * 状态
     */
    private String status;

    /**
     * 添加构建转换成实体类对象
     * @param req 支付客户添加请求对象
     * @return 实体类对象
     */
    public static OrderPayCustomer addBuild(OrderCustomerAddReq req) {
        return OrderPayCustomer.builder()
                .appName(req.getAppName())
                .appCode(req.getAppCode())
                .appDesc(req.getAppDesc())
                .status(req.getStatus())
                .remark(req.getRemark())
                .build();
    }

    /**
     * 修改构建者转换成实体类对象
     * @param req 支付客户修改请求对象
     * @param idSupplier 支付客户修改ID
     * @return 实体类对象
     */
    public static OrderPayCustomer updateBuild(OrderCustomerUpdateReq req, Supplier<Long> idSupplier) {
        return OrderPayCustomer.builder()
                .id(idSupplier.get())
                .appName(req.getAppName())
                .appDesc(req.getAppDesc())
                .status(req.getStatus())
                .remark(req.getRemark())
                .build();
    }
}